# coding: utf-8

"""
    Kubeflow Pipelines API

    This file contains REST API specification for Kubeflow Pipelines. The file is autogenerated from the swagger definition.

    Contact: kubeflow-pipelines@google.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import kfp_server_api
from kfp_server_api.api.job_service_api import JobServiceApi  # noqa: E501
from kfp_server_api.rest import ApiException


class TestJobServiceApi(unittest.TestCase):
    """JobServiceApi unit test stubs"""

    def setUp(self):
        self.api = kfp_server_api.api.job_service_api.JobServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_job(self):
        """Test case for create_job

        Creates a new job.  # noqa: E501
        """
        pass

    def test_delete_job(self):
        """Test case for delete_job

        Deletes a job.  # noqa: E501
        """
        pass

    def test_disable_job(self):
        """Test case for disable_job

        Stops a job and all its associated runs. The job is not deleted.  # noqa: E501
        """
        pass

    def test_enable_job(self):
        """Test case for enable_job

        Restarts a job that was previously stopped. All runs associated with the job will continue.  # noqa: E501
        """
        pass

    def test_get_job(self):
        """Test case for get_job

        Finds a specific job by ID.  # noqa: E501
        """
        pass

    def test_list_jobs(self):
        """Test case for list_jobs

        Finds all jobs.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
